public inbox for gentoo-commits@lists.gentoo.org
 help / color / mirror / Atom feed
* [gentoo-commits] proj/toolchain/glibc-patches:master commit in: /
@ 2020-05-14 12:44 Andreas K. Hüttel
  0 siblings, 0 replies; 2+ messages in thread
From: Andreas K. Hüttel @ 2020-05-14 12:44 UTC (permalink / raw
  To: gentoo-commits

commit:     0374816013765ce62786243b695b8d98c6e8a2ef
Author:     Andreas K. Hüttel <dilfridge <AT> gentoo <DOT> org>
AuthorDate: Thu May 14 12:44:02 2020 +0000
Commit:     Andreas K. Hüttel <dilfridge <AT> gentoo <DOT> org>
CommitDate: Thu May 14 12:44:40 2020 +0000
URL:        https://gitweb.gentoo.org/proj/toolchain/glibc-patches.git/commit/?id=03748160

Update make-tarball.sh for separate glibc and glibc-patches repos

Signed-off-by: Andreas K. Hüttel <dilfridge <AT> gentoo.org>

 make-tarball.sh | 55 ++++++++++++++++++++++++++++++++++++++++++-------------
 1 file changed, 42 insertions(+), 13 deletions(-)

diff --git a/README.Gentoo.patches b/README.Gentoo.patches
index c6f94dc..b6ac163 100644
--- a/README.Gentoo.patches
+++ b/README.Gentoo.patches
@@ -15,7 +15,11 @@ original creators, etc...
  === Where ===
  =============
 
-Currently, https://github.com/gentoo/glibc
+https://gitweb.gentoo.org/fork/glibc.git/
+
+The patch generation script and the base patchset for the start of a new
+version branch (or for use with glibc git master) can be found at
+https://gitweb.gentoo.org/proj/toolchain/glibc-patches.git/
 
  ===========
  === How ===
@@ -24,3 +28,6 @@ Currently, https://github.com/gentoo/glibc
 Patches are named exactly as generated by "git format-patch".
 All patches thus apply with -p1 (so they can be used both with the legacy
 epatch function and the new, more strict eapply function).
+
+
+ -----------

diff --git a/make-tarball.sh b/make-tarball.sh
index 1063e1b..c3ac509 100755
--- a/make-tarball.sh
+++ b/make-tarball.sh
@@ -44,6 +44,8 @@ if [[ ! -z "${mystatusinfo}" ]] ; then
 	exit 1
 fi
 
+mydescpatches=$(git describe)
+
 # go into the gentoo glibc repo
 
 cd "${mypathglibc}"
@@ -65,6 +67,8 @@ if [[ ! -z "${mystatusinfo}" ]] ; then
 	exit 1
 fi
 
+mydescglibc=$(git describe)
+
 # check if the tag already exists
 
 mytaginfo=$(git tag -l|grep "gentoo/glibc-${PV}-${pver}")
@@ -96,6 +100,9 @@ mkdir -p tmp/patches
 
 cp "${mypathpatches}/README.Gentoo.patches" tmp/ || exit 1
 
+echo >> "tmp/README.Gentoo.patches"
+echo "Generated with make-tarball.sh ${mydescpatches}" >> "tmp/README.Gentoo.patches"
+
 # create and rename patches
 
 if [[ "${PV}" == "9999" ]]; then


^ permalink raw reply related	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2020-06-09 20:51 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2020-06-09 20:51 [gentoo-commits] proj/toolchain/glibc-patches:master commit in: / Andreas K. Hüttel
  -- strict thread matches above, loose matches on Subject: below --
2020-05-14 12:44 Andreas K. Hüttel

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
diff --git a/make-tarball.sh b/make-tarball.sh
index a4f380d..1063e1b 100755
--- a/make-tarball.sh
+++ b/make-tarball.sh
@@ -1,28 +1,59 @@
 #!/bin/bash
 
+mypathglibc=${GENTOO_GLIBC_REPO:-~/Gentoo/misc/glibc}
+mypathpatches=${GENTOO_GLIBC_PATCHES_REPO:-~/Gentoo/misc/glibc-patches}
+
+# I plan to extend this script a bit, to also help with the initial
+# Gentoo release branch creation. That's why I check so much for both
+# git repos... -A
+
 PN="glibc"
 PV=${1%/}
 pver=$2
 
 if [[ -z ${PV} ]] ; then
 	echo "Usage: $0 glibc-version patchset-version-to-be-created"
+	echo "Important environment variables: GENTOO_GLIBC_REPO GENTOO_GLIBC_PATCHES_REPO"
 	echo "Please read the script before trying to use it :)"
 	exit 1
 fi
 
-# check that we're in the root of a glibc git repo
+# check that we have a gentoo glibc patches git repo
+
+if [[ ! -f "${mypathpatches}/README.Gentoo.patches" ]] || [[ ! -d "${mypathpatches}/.git" ]] ; then
+	echo "Error: GENTOO_GLIBC_PATCHES_REPO needs to point to the main directory of a Gentoo glibc patchset git clone"
+	exit 1
+fi
+
+# check that we have a gentoo glibc git repo
 
-if [[ ! -f libc-abis ]] || [[ ! -d .git ]] ; then
-	echo "Error: You need to call this script in the main directory of a Gentoo glibc git clone"
+if [[ ! -f "${mypathglibc}/libc-abis" ]] || [[ ! -d "${mypathglibc}/.git" ]] ; then
+	echo "Error: GENTOO_GLIBC_REPO needs to point to the main directory of a Gentoo glibc git clone"
 	exit 1
 fi
 
+# go into the gentoo patches repo
+
+cd "${mypathpatches}"
+
+# check that the working directory is clean
+
+mystatusinfo=$(git status --porcelain)
+if [[ ! -z "${mystatusinfo}" ]] ; then
+	echo "Error: Your glibc patches working directory is not clean"
+	exit 1
+fi
+
+# go into the gentoo glibc repo
+
+cd "${mypathglibc}"
+
 # check that we're on a branch gentoo/${PV}
 
 mybranchinfo=$(git status --porcelain -b|grep '^##')
 mybranch=$(echo ${mybranchinfo}|sed -e 's:^## ::' -e 's:\.\.\..*$::')
 if [[ ! "gentoo/${PV}" == "${mybranch}" ]] ; then
-	echo "Error: Your git repository is on the incorrect branch ${mybranch}; should be gentoo/${PV}"
+	echo "Error: Your glibc git repository is on the incorrect branch ${mybranch}; should be gentoo/${PV}"
 	exit 1
 fi
 
@@ -30,7 +61,7 @@ fi
 
 mystatusinfo=$(git status --porcelain)
 if [[ ! -z "${mystatusinfo}" ]] ; then
-	echo "Error: Your working directory is not clean"
+	echo "Error: Your glibc working directory is not clean"
 	exit 1
 fi
 
@@ -63,13 +94,14 @@ mkdir -p tmp/patches
 
 # copy README.Gentoo.patches
 
-cp scripts/gentoo/README.Gentoo.patches tmp/ || exit 1
+cp "${mypathpatches}/README.Gentoo.patches" tmp/ || exit 1
 
 # create and rename patches
 
 if [[ "${PV}" == "9999" ]]; then
-	# we're working with master, start from upstream master
-	startpoint="master"
+	# working with master is not supported anymore
+	echo "Patchsets for git master are not supported anymore"
+    exit 1
 else
 	# release branch, start from upstream release tag
 	startpoint="glibc-${PV}"
@@ -78,6 +110,7 @@ fi
 git format-patch ${startpoint}..HEAD > /dev/null
 
 # remove all patches where the summary line starts with [no-tarball] or [no-patch]
+# this should not be needed anymore (no such commits), we can remove it once we're sure
 
 rm -f 0???-no-tarball-*.patch
 rm -f 0???-no-patch-*.patch
@@ -86,10 +119,6 @@ rm -f 0???-no-patch-*.patch
 
 mv 0*.patch tmp/patches/ || exit 1
 
-# copy support files
-
-cp -r scripts/gentoo/extra tmp/ || exit 1
-
 # add a history file
 
 git log --stat --decorate ${startpoint}..HEAD > tmp/patches/README.history || exit 1
@@ -97,7 +126,7 @@ git log --stat --decorate ${startpoint}..HEAD > tmp/patches/README.history || ex
 # package everything up
 
 tar -Jcf ${PN}-${PV}-patches-${pver}.tar.xz \
-	-C tmp patches extra README.Gentoo.patches || exit 1
+	-C tmp patches README.Gentoo.patches || exit 1
 rm -r tmp
 
 du -b *.tar.xz


^ permalink raw reply related	[flat|nested] 2+ messages in thread

* [gentoo-commits] proj/toolchain/glibc-patches:master commit in: /
@ 2020-06-09 20:51 Andreas K. Hüttel
  0 siblings, 0 replies; 2+ messages in thread
From: Andreas K. Hüttel @ 2020-06-09 20:51 UTC (permalink / raw
  To: gentoo-commits

commit:     2444bf09ee2324730cb0cbe9b5180c813e19bfb4
Author:     Andreas K. Hüttel <dilfridge <AT> gentoo <DOT> org>
AuthorDate: Tue Jun  9 20:50:38 2020 +0000
Commit:     Andreas K. Hüttel <dilfridge <AT> gentoo <DOT> org>
CommitDate: Tue Jun  9 20:51:21 2020 +0000
URL:        https://gitweb.gentoo.org/proj/toolchain/glibc-patches.git/commit/?id=2444bf09

Update readme and record used make-tarball.sh version in tarball

Signed-off-by: Andreas K. Hüttel <dilfridge <AT> gentoo.org>

 README.Gentoo.patches | 9 ++++++++-
 make-tarball.sh       | 7 +++++++
 2 files changed, 15 insertions(+), 1 deletion(-)
